package betterquesting.questing.tasks;

import betterquesting.api.placeholders.tasks.FactoryTaskPlaceholder;
import betterquesting.api.placeholders.tasks.TaskPlaceholder;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.IDatabaseNBT;
import betterquesting.api2.storage.SimpleDatabase;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_questing_tasks.jar:betterquesting/questing/tasks/TaskStorage.class */
public class TaskStorage extends SimpleDatabase<ITask> implements IDatabaseNBT<ITask, NBTTagList, NBTTagList> {
    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public /* bridge */ /* synthetic */ NBTBase writeProgressToNBT(NBTBase nBTBase, List list) {
        return writeProgressToNBT((NBTTagList) nBTBase, (List<UUID>) list);
    }

    public NBTTagList writeToNBT(NBTTagList json, @Nullable List<Integer> subset) {
        for (DBEntry<ITask> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                ResourceLocation taskID = ((ITask) entry.getValue()).getFactoryID();
                NBTTagCompound qJson = ((ITask) entry.getValue()).writeToNBT(new NBTTagCompound());
                qJson.func_74778_a("taskID", taskID.toString());
                qJson.func_74768_a("index", entry.getID());
                json.func_74742_a(qJson);
            }
        }
        return json;
    }

    public void readFromNBT(NBTTagList json, boolean merge) {
        if (!merge) {
            reset();
        }
        List<ITask> unassigned = new ArrayList<>();
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jsonTask = json.func_150305_b(i);
            ResourceLocation loc = new ResourceLocation(jsonTask.func_74779_i("taskID"));
            int index = jsonTask.func_150297_b("index", 99) ? jsonTask.func_74762_e("index") : -1;
            ITask task = TaskRegistry.INSTANCE.m1createNew(loc);
            if (task instanceof TaskPlaceholder) {
                NBTTagCompound jt2 = jsonTask.func_74775_l("orig_data");
                ResourceLocation loc2 = new ResourceLocation(jt2.func_74779_i("taskID"));
                ITask t2 = TaskRegistry.INSTANCE.m1createNew(loc2);
                if (t2 != null) {
                    jsonTask = jt2;
                    task = t2;
                }
            }
            if (task != null) {
                task.readFromNBT(jsonTask);
            } else {
                task = new TaskPlaceholder();
                ((TaskPlaceholder) task).setTaskConfigData(jsonTask);
            }
            if (index >= 0) {
                add(index, task);
            } else {
                unassigned.add(task);
            }
        }
        for (ITask t : unassigned) {
            add(nextID(), t);
        }
    }

    public NBTTagList writeProgressToNBT(NBTTagList json, List<UUID> users) {
        for (DBEntry<ITask> entry : getEntries()) {
            ResourceLocation taskID = ((ITask) entry.getValue()).getFactoryID();
            NBTTagCompound qJson = ((ITask) entry.getValue()).writeProgressToNBT(new NBTTagCompound(), users);
            qJson.func_74778_a("taskID", taskID.toString());
            qJson.func_74768_a("index", entry.getID());
            json.func_74742_a(qJson);
        }
        return json;
    }

    public void readProgressFromNBT(NBTTagList json, boolean merge) {
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jsonTask = json.func_150305_b(i);
            int index = jsonTask.func_150297_b("index", 99) ? jsonTask.func_74762_e("index") : -1;
            ResourceLocation loc = new ResourceLocation(jsonTask.func_74779_i("taskID"));
            TaskPlaceholder taskPlaceholder = (ITask) getValue(index);
            if (taskPlaceholder instanceof TaskPlaceholder) {
                if (!taskPlaceholder.getFactoryID().equals(loc)) {
                    taskPlaceholder.setTaskProgressData(jsonTask);
                } else {
                    taskPlaceholder.readProgressFromNBT(jsonTask, false);
                }
            } else if (taskPlaceholder != null) {
                if (taskPlaceholder.getFactoryID().equals(loc)) {
                    taskPlaceholder.readProgressFromNBT(jsonTask, false);
                } else if (FactoryTaskPlaceholder.INSTANCE.getRegistryName().equals(loc)) {
                    taskPlaceholder.readProgressFromNBT(jsonTask.func_74775_l("orig_prog"), false);
                }
            }
        }
    }
}
